/** -*- mode: c++ ; c-basic-offset: 2 -*-
 *
 *  @file FilterTreeFolder.h
 *
 *  Copyright 2017 Sebastien Fourey
 *
 *  This file is part of G'MIC-Qt, a generic plug-in for raster graphics
 *  editors, offering hundreds of filters thanks to the underlying G'MIC
 *  image processing framework.
 *
 *  gmic_qt is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  gmic_qt is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with gmic_qt.  If not, see <http://www.gnu.org/licenses/>.
 *
 */
#ifndef GMIC_QT_FILTERTREEFOLDER_H
#define GMIC_QT_FILTERTREEFOLDER_H
#include <QStandardItem>
#include <QString>
#include "FilterSelector/FiltersView/FilterTreeAbstractItem.h"

class FilterTreeFolder : public FilterTreeAbstractItem {
public:
  FilterTreeFolder(const QString & text);
  void setFaveFolderFlag(bool);
  bool isFullyUnchecked();
  bool isFaveFolder() const;
  bool operator<(const QStandardItem & other) const override;
  void applyVisibilityStatusToFolderContents();
  void setItemsVisibility(bool visible);

private:
  bool _isFaveFolder;
};

#endif // GMIC_QT_FILTERTREEFOLDER_H
